import os
import sys
import getopt
import mistletoe
from .jira_renderer import JIRARenderer

usageString = '%s <markdownfile>' % os.path.basename(sys.argv[0])
helpString = """
Convert Markdown (CommonMark) to JIRA wiki markup
-h, --help                        help
-v, --version                     version
-o <outfile>, --output=<outfile>  output file, use '-' for stdout (default: stdout)
If no input file is specified, stdin is used.
"""

"""
Command-line utility to convert Markdown (CommonMark) to JIRA markup.
JIRA markup spec: https://jira.atlassian.com/secure/WikiRendererHelpAction.jspa?section=all
CommonMark spec: http://spec.commonmark.org/0.28/#introduction
"""


def main():
    try:
        optlist, args = getopt.getopt(sys.argv[1:], 'hvo:',
                                        ['help',
                                        'version',
                                        'output='])

    except getopt.GetoptError as err:
        sys.stderr.write(err.msg + '\n')
        sys.stderr.write(usageString + '\n')
        sys.exit(1)

    app = MarkdownToJIRA()
    app.run(optlist, args)


class MarkdownToJIRA:
    def __init__(self):
        self.version = "1.0.2"
        self.options = {}
        self.options['output'] = '-'

    def run(self, optlist, args):
        for o, i in optlist:
            if o in ('-h', '--help'):
                sys.stderr.write(usageString + '\n')
                sys.stderr.write(helpString + '\n')
                sys.exit(1)

            elif o in ('-v', '--version'):
                sys.stdout.write('%s\n' % self.version)
                sys.exit(0)

            elif o in ('-o', '--output'):
                self.options['output'] = i

        if len(args) < 1:
            sys.stderr.write(usageString + '\n')
            sys.exit(1)

        with open(args[0], 'r') if len(args) == 1 else sys.stdin as infile:
            rendered = mistletoe.markdown(infile, JIRARenderer)

        if self.options['output'] == '-':
            sys.stdout.write(rendered)
        else:
            with open(self.options['output'], 'w') as outfile:
                outfile.write(rendered)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['md2jira']

package_data = \
{'': ['*']}

install_requires = \
['mistletoe>=0.8.2,<0.9.0']

entry_points = \
{'console_scripts': ['md2jira = md2jira.md2jira:main']}

setup_kwargs = {
    'name': 'md2jira',
    'version': '1.0.2a0',
    'description': 'Markdown to jira',
    'long_description': '# md2jira\n\n[![PyPI](https://img.shields.io/pypi/v/md2jira)](https://pypi.org/project/md2jira/)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/md2jira)](https://www.python.org/downloads/)\n[![GitHub last commit](https://img.shields.io/github/last-commit/daxartio/md2jira)](https://github.com/daxartio/md2jira)\n[![GitHub stars](https://img.shields.io/github/stars/daxartio/md2jira?style=social)](https://github.com/daxartio/md2jira)\n\n```\npip install md2jira\n```\n\nAlso try `pandoc`\n\n```\npandoc in.md -o out.txt --to jira\n```\n\n## Contributing\n\n[Contributing](CONTRIBUTING.md)\n\n## Get started\n\n```\nmd2jira --help\n```\n\nThis project was forked\n',
    'author': 'Danil Akhtarov',
    'author_email': 'daxartio@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://pypi.org/project/md2jira',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
